module :py:mod:`tarantool.msgpack_ext.types`
============================================

.. currentmodule:: tarantool.msgpack_ext.types

module :py:mod:`tarantool.msgpack_ext.types.datetime`
-----------------------------------------------------

.. automodule:: tarantool.msgpack_ext.types.datetime
   :special-members: __add__, __sub__, __eq__


.. currentmodule:: tarantool.msgpack_ext.types

module :py:mod:`tarantool.msgpack_ext.types.interval`
-----------------------------------------------------

.. automodule:: tarantool.msgpack_ext.types.interval
   :special-members: __add__, __sub__, __eq__
